@@ -27,7 +27,9 @@ use constant {
     SiteSpecificExtractorByHost => {
         'www.allnews.tw' => 'NewsExtractor::SiteSpecificExtractor::www_allnews_tw',
         'www.rvn.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_rvn_com_tw',
-        'www.chinatimes.com' => 'NewsExtractor::JSONLDExtractor',
+        'www.chinatimes.com{' => 'NewsExtractor::JSONLDExtractor',
+        'video.udn.com' => 'NewsExtractor::JSONLDExtractor',
+        'www.ctwant.com' => 'NewsExtractor::JSONLDExtractor',
     },
     CSSRuleSetByHost => {
         'www.epochtimes.com' => {
